@@ -1,11 +1,5 @@
 package CGI::Wiki::Plugin::Bar;
-use vars qw( @ISA );
-@ISA = qw( CGI::Wiki::Plugin );
-
-sub new {
-    my $class = shift;
-    return bless {}, $class;
-}
+use base qw( CGI::Wiki::Plugin );
 
 sub on_register {
     my $self = shift;
